![Valaw Banner](https://raw.githubusercontent.com/Jet612/valaw/main/assets/banner.png)


[![PyPI Version](https://img.shields.io/pypi/v/valaw?style=for-the-badge)](https://pypi.org/project/valaw/)
[![GitHub Issues](https://img.shields.io/github/issues/jet612/valaw?style=for-the-badge)](https://github.com/Jet612/valaw/issues)
[![PyPI Downloads](https://img.shields.io/pypi/dm/valaw?style=for-the-badge)](https://pypi.org/project/valaw/)
[![Python Version](https://img.shields.io/pypi/pyversions/valaw?style=for-the-badge)](https://www.python.org/)
[![GitHub Contributors](https://img.shields.io/github/contributors/jet612/valaw?style=for-the-badge)](https://github.com/Jet612/valaw/graphs/contributors)


valaw is an asynchronous API wrapper for VALORANT's API.

# Documentation
The documentation for this wrapper can be found [here](https://valaw.readthedocs.io/). Read the documentation to learn how to get started with valaw.
The documentation also has a list of all the endpoints and examples on how to use them.

# Help/Support
If you need help/support with valaw, you can join the [Discord Server](https://discord.gg/mVXpvunBbF). If you have incountered a bug, you can also open an issue on the [GitHub repository](https://github.com/Jet612/valaw/issues).

# Quick Links
- [Discord](https://discord.gg/mVXpvunBbF)
- [PyPI](https://pypi.org/project/valaw/)
- [GitHub](https://github.com/Jet612/valaw)
- [Documentation](https://valaw.readthedocs.io/)

This project is owned and maintained by Jet612, other contributors can be found [here](https://github.com/Jet612/valaw/graphs/contributors)
